@@ -5,6 +5,7 @@ from playsound import playsound
 # creating class to implement custom getch of msvcrt module getch fucntion for windows and linux seperately
 class _Getch:
     """Gets a single character from standard input.  Does not echo to the screen."""
+
     def __init__(self):
         try:
             self.impl = _GetchWindows()
@@ -17,10 +18,13 @@ class _Getch:
 # class of custom getch function for unix system
 class _GetchUnix:
     def __init__(self):
-        import tty, sys
+        import tty
+        import sys
 
     def __call__(self):
-        import sys, tty, termios
+        import sys
+        import tty
+        import termios
         fd = sys.stdin.fileno()
         old_settings = termios.tcgetattr(fd)
         try:
@@ -30,7 +34,9 @@ class _GetchUnix:
             termios.tcsetattr(fd, termios.TCSADRAIN, old_settings)
         return ch
 
-# class for custom module of getch function for windows system 
+# class for custom module of getch function for windows system
+
+
 class _GetchWindows:
     def __init__(self):
         import msvcrt
@@ -46,9 +52,9 @@ getch = _Getch()
 
 # thread for enter key sound
 class enterSound(Thread):
-    # function name should be run 
+    # function name should be run
 
-    def setPath(self , path):
+    def setPath(self, path):
         self.path = path
 
     def run(self):
@@ -56,7 +62,6 @@ class enterSound(Thread):
             playsound(self.path)
         except Exception:
             raise Exception("please download the enter sound file from link and pass it to setEnterAudioPath() , link - https://drive.google.com/uc?export=download&id=1mN_-vyRsHWK8qsHP16ktL9G0XX3RCbB9 . If the file is not available to download then you can download the file from here - https://github.com/harshnative/easyTypeWriter_module_python/tree/master/easyTypeWriter")
-        
 
 
 # function to play keyboard sound at 30% extra speed
@@ -69,7 +74,7 @@ def sound30():
 
 # main module class
 class EasyInput:
-    
+
     # constructor
     def __init__(self):
 
@@ -79,143 +84,144 @@ class EasyInput:
         self.enterAudioPath = None
         self.keyboardAudioPath = None
 
-
         # byte code character dictionary
         self.dict = {
-            # numbers - 
+            # numbers -
 
-                b'1' : "1" , 
-                b'2' : "2" , 
-                b'3' : "3" , 
-                b'4' : "4" , 
-                b'5' : "5" , 
-                b'6' : "6" , 
-                b'7' : "7" , 
-                b'8' : "8" , 
-                b'9' : "9" , 
-                b'0' : "0" , 
+            b'1': "1",
+            b'2': "2",
+            b'3': "3",
+            b'4': "4",
+            b'5': "5",
+            b'6': "6",
+            b'7': "7",
+            b'8': "8",
+            b'9': "9",
+            b'0': "0",
 
-            # characters Upper case - 
+            # characters Upper case -
 
-                b'Q' : "Q" , 
-                b'W' : "W" , 
-                b'E' : "E" , 
-                b'R' : "R" , 
-                b'T' : "T" , 
-                b'Y' : "Y" , 
-                b'U' : "U" , 
-                b'I' : "I" , 
-                b'O' : "O" , 
-                b'P' : "P" , 
-                b'A' : "A" , 
-                b'S' : "S" , 
-                b'D' : "D" , 
-                b'F' : "F" , 
-                b'G' : "G" , 
-                b'H' : "H" , 
-                b'J' : "J" , 
-                b'K' : "K" , 
-                b'L' : "L" , 
-                b'Z' : "Z" , 
-                b'X' : "X" , 
-                b'C' : "C" , 
-                b'V' : "V" , 
-                b'B' : "B" , 
-                b'N' : "N" , 
-                b'M' : "M" , 
+            b'Q': "Q",
+            b'W': "W",
+            b'E': "E",
+            b'R': "R",
+            b'T': "T",
+            b'Y': "Y",
+            b'U': "U",
+            b'I': "I",
+            b'O': "O",
+            b'P': "P",
+            b'A': "A",
+            b'S': "S",
+            b'D': "D",
+            b'F': "F",
+            b'G': "G",
+            b'H': "H",
+            b'J': "J",
+            b'K': "K",
+            b'L': "L",
+            b'Z': "Z",
+            b'X': "X",
+            b'C': "C",
+            b'V': "V",
+            b'B': "B",
+            b'N': "N",
+            b'M': "M",
 
             # characters lower case -
 
-                b'q' : "q" , 
-                b'w' : "w" , 
-                b'e' : "e" , 
-                b'r' : "r" , 
-                b't' : "t" , 
-                b'y' : "y" , 
-                b'u' : "u" , 
-                b'i' : "i" , 
-                b'o' : "o" , 
-                b'p' : "p" , 
-                b'a' : "a" , 
-                b's' : "s" , 
-                b'd' : "d" , 
-                b'f' : "f" , 
-                b'g' : "g" , 
-                b'h' : "h" , 
-                b'j' : "j" , 
-                b'k' : "k" , 
-                b'l' : "l" , 
-                b'z' : "z" , 
-                b'x' : "x" , 
-                b'c' : "c" , 
-                b'v' : "v" , 
-                b'b' : "b" ,
-                b'n' : "n" , 
-                b'm' : "m" , 
+            b'q': "q",
+            b'w': "w",
+            b'e': "e",
+            b'r': "r",
+            b't': "t",
+            b'y': "y",
+            b'u': "u",
+            b'i': "i",
+            b'o': "o",
+            b'p': "p",
+            b'a': "a",
+            b's': "s",
+            b'd': "d",
+            b'f': "f",
+            b'g': "g",
+            b'h': "h",
+            b'j': "j",
+            b'k': "k",
+            b'l': "l",
+            b'z': "z",
+            b'x': "x",
+            b'c': "c",
+            b'v': "v",
+            b'b': "b",
+            b'n': "n",
+            b'm': "m",
 
-            # upper num line - 
+            # upper num line -
 
-                b'!' : "!" , 
-                b'@' : "@" , 
-                b'#' : "#" , 
-                b'$' : "$" , 
-                b'%' : "%" , 
-                b'^' : "^" , 
-                b'&' : "&" , 
-                b'*' : "*" , 
-                b'(' : "(" , 
-                b')' : ")" , 
+            b'!': "!",
+            b'@': "@",
+            b'#': "#",
+            b'$': "$",
+            b'%': "%",
+            b'^': "^",
+            b'&': "&",
+            b'*': "*",
+            b'(': "(",
+            b')': ")",
 
-            # other special characters - 
+            # other special characters -
 
-                b'`' : "`" ,
-                b'~' : "~" ,
-                b'-' : "-" ,
-                b'_' : "_" ,
-                b'=' : "=" ,
-                b'+' : "+" ,
-                b'[' : "[" ,
-                b']' : "]" ,
-                b'{' : "{" ,
-                b'}' : "}" ,
-                b'\\' : "\\" ,
-                b'|' : "|" ,
-                b'"' : '"' ,
-                b"'" : "'" ,
-                b';' : ";" ,
-                b':' : ":" ,
-                b'/' : "/" ,
-                b'?' : "?" ,
-                b'.' : "." ,
-                b'>' : ">" ,
-                b'<' : "<" ,
-                b',' : "," ,
+            b'`': "`",
+            b'~': "~",
+            b'-': "-",
+            b'_': "_",
+            b'=': "=",
+            b'+': "+",
+            b'[': "[",
+            b']': "]",
+            b'{': "{",
+            b'}': "}",
+            b'\\': "\\",
+            b'|': "|",
+            b'"': '"',
+            b"'": "'",
+            b';': ";",
+            b':': ":",
+            b'/': "/",
+            b'?': "?",
+            b'.': ".",
+            b'>': ">",
+            b'<': "<",
+            b',': ",",
         }
 
-    
     # set tab space value function only pass positive integer
+
     def setTabSpaceValue(self, value):
         try:
             self.tabValue = int(value)
             if(self.tabValue < 0):
-                raise ValueError("please pass only positive integer value to setTabSpaceValue function")
+                raise ValueError(
+                    "please pass only positive integer value to setTabSpaceValue function")
         except Exception:
-            raise ValueError("please pass only positive integer value to setTabSpaceValue function")
-
+            raise ValueError(
+                "please pass only positive integer value to setTabSpaceValue function")
 
     # set enter sound audio file path
+
     def setEnterAudioPath(self, fullPath):
         self.enterAudioPath = fullPath
 
     # set enter sound audio file path
     def setKeyboardAudioPath(self, fullPath):
-        self.keyboardAudioPath = fullPath    
+        self.keyboardAudioPath = fullPath
 
     # main function of the module
-    def takeInput(self , makeSound = True , messagePrompt = "" , toReturn = False):
+    def takeInput(self, makeSound=True, messagePrompt="" , toNextLineOnEnter=True , toReturn=False):
         if((self.enterAudioPath == None)):
             raise Exception("please download the enter sound file from link and pass it to setEnterAudioPath() , link - https://drive.google.com/uc?export=download&id=1mN_-vyRsHWK8qsHP16ktL9G0XX3RCbB9 . If the file is not available to download then you can download the file from here - https://github.com/harshnative/easyTypeWriter_module_python/tree/master/easyTypeWriter")
-        
+
         if((self.keyboardAudioPath == None)):
             raise Exception("please download the keyboard sound file from link and pass it to setKeyboardAudioPath() , link - https://drive.google.com/uc?export=download&id=1qGSaacUgs6MEoI18W0uQOTq5yYSwo_Iv . If the file is not available to download then you can download the file from here - https://github.com/harshnative/easyTypeWriter_module_python/tree/master/easyTypeWriter")
 
@@ -226,14 +232,14 @@ class EasyInput:
         objEnter.setPath(self.enterAudioPath)
 
         while(1):
-            
-            #printing the string to show the visual output 
-            print("\r{}".format(string) , end = "")
+
+            # printing the string to show the visual output
+            print("\r{}".format(string), end="")
             x = getch()
-            
+
             # if the item is not found in dictionary
             if(self.dict.get(x) == None):
-                
+
                 # if the key pressed is enter
                 if(x == b"\r"):
 
@@ -241,6 +247,11 @@ class EasyInput:
                     if(makeSound):
                         objEnter.start()
 
+                    # making "\n" , like normal input function does 
+
+                    if(toNextLineOnEnter):
+                    	print("\n" , end = "")
+
                     # returning the string by cutting the message prompt from the string
                     return string[messageLength:]
 
@@ -250,28 +261,27 @@ class EasyInput:
                     l = len(string)
 
                     # backspace should not earse the message prompt itself
-                    if(l <= messageLength):
-                        pass
-                    else:
-                    	if(makeSound):
-                        	playsound(self.keyboardAudioPath)
+                    if(l > messageLength):
+
+                        if(makeSound):
+                            playsound(self.keyboardAudioPath)
 
                         # erasing the string element by one for one backspace
                         string = string[:l-1]
-                        print("\r" , end = "")
+                        print("\r", end="")
 
                         # clearing the line so that new backspaced line can be printed when teh while loop starts
                         while(l):
-                            print(" " , end = "")
+                            print(" ", end="")
                             l -= 1
 
-                # if the key pressed is backspace the add " " to the string 
+                # if the key pressed is backspace the add " " to the string
                 elif(x == b' '):
                     if(makeSound):
                         playsound(self.keyboardAudioPath)
                     string = string + " "
 
-                # if the key pressed is tab then add ( " " * self.tabValue ) to teh string 
+                # if the key pressed is tab then add ( " " * self.tabValue ) to teh string
                 elif(x == b'\t'):
                     if(makeSound):
                         playsound(self.keyboardAudioPath)
@@ -281,7 +291,7 @@ class EasyInput:
                 # if a unrecognised key is pressed then module does nothing
                 else:
                     pass
-            
+
             # adding value from the dictionary to the string
             else:
                 if(makeSound):
@@ -292,19 +302,19 @@ class EasyInput:
             # returning if required
             if(toReturn):
                 return string[messageLength:]
-            
+
 
 # for testing purpose only
 if __name__ == "__main__":
-    obj = EasyInput()            
+    obj = EasyInput()
     print("started")
     obj.setEnterAudioPath("C:/users/harsh/desktop/ding3.wav")
     obj.setKeyboardAudioPath("C:/users/harsh/desktop/keysound30.wav")
-    x = obj.takeInput(True , "input : " )
-    print("\n" , x , sep= "")
-    x = obj.takeInput(True , "input : " )
-    print("\n" , x , sep= "")
-    x = obj.takeInput(True , "input : " )
-    print("\n" , x , sep= "")
-    x = obj.takeInput(True , "input : " )
-    print("\n" , x , sep= "")
+    x = obj.takeInput(True, "input : ")
+    print("\n", x, sep="")
+    x = obj.takeInput(True, "input : ")
+    print("\n", x, sep="")
+    x = obj.takeInput(True, "input : ")
+    print("\n", x, sep="")
+    x = obj.takeInput(True, "input : ")
+    print("\n", x, sep="")
